@@ -23,7 +23,7 @@
 #include <config.h>
 #endif
 
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include "time-out-countdown.h"
 
 
@@ -472,38 +472,28 @@ time_out_countdown_seconds_to_string (gint     seconds,
             {
               if (hours <= 0)
                 {
-                  if (minutes < 1)
-                    {
-                      /* Do not show 0 minutes */
-                      minutes = 1;
-                    }
                   if (seconds == 0)
                     g_string_printf (str, _("Time left: %s"), mins);
                   else
                     {
                       /* Round up the number of minutes */
-                      mins = g_strdup_printf (ngettext ("%d minute", "%d minutes", minutes), minutes + 1);
-                      g_string_printf (str, _("Time left: %s"), mins);
                       g_free (mins);
+                      mins = g_strdup_printf (ngettext ("%d minute", "%d minutes", minutes + 1), minutes + 1);
+                      g_string_printf (str, _("Time left: %s"), mins);
                     }
                 }
               else 
                 {
-                  if (minutes < 1)
-                    {
-                    /* Do not show 0 minutes */
-                    minutes = 1;
-                    }
                   if (seconds == 0)
                     /* Translators: this is %s hours, %s minutes */
                     g_string_printf (str, _("Time left: %s %s"), hrs, mins);
                   else
                     {
                       /* Round up the number of minutes */
-                      mins = g_strdup_printf (ngettext ("%d minute", "%d minutes", minutes), minutes + 1);
+                      g_free (mins);
+                      mins = g_strdup_printf (ngettext ("%d minute", "%d minutes", minutes + 1), minutes + 1);
                       /* Translators: this is %s hours, %s minutes */
                       g_string_printf (str, _("Time left: %s %s"), hrs, mins);
-                      g_free (mins);
                     }
                 }
             }
@@ -529,19 +519,14 @@ time_out_countdown_seconds_to_string (gint     seconds,
             }
           else
             {
-              if (minutes < 1) 
-                {
-                  /* Do not show 0 minutes */
-                  minutes = 1; 
-                }
               if (seconds == 0)
                 g_string_printf (str, _("Time left: %s"), mins);
               else
                 {
                   /* Round up the number of minutes */
-                  mins = g_strdup_printf (ngettext ("%d minute", "%d minutes", minutes), minutes + 1);
-                  g_string_printf (str, _("Time left: %s"), mins);
                   g_free (mins);
+                  mins = g_strdup_printf (ngettext ("%d minute", "%d minutes", minutes + 1), minutes + 1);
+                  g_string_printf (str, _("Time left: %s"), mins);
                 }
             }
         }
@@ -558,17 +543,20 @@ time_out_countdown_update (TimeOutCountdown *countdown)
 {
   g_return_val_if_fail (IS_TIME_OUT_COUNTDOWN (countdown), FALSE);
 
-  /* Emit a regular 'update' signal */
-  g_signal_emit_by_name (countdown, "update", time_out_countdown_get_remaining (countdown));
-
-  /* If the countdown has passed the requested seconds, emit a 'finish' signal */
-  if (time_out_countdown_get_running (countdown) && time_out_countdown_get_remaining (countdown) <= 0)
+  if (time_out_countdown_get_running (countdown))
     {
-      /* Set state to stopped */
-      time_out_countdown_stop (countdown);
+      /* Emit a regular 'update' signal */
+      g_signal_emit_by_name (countdown, "update", time_out_countdown_get_remaining (countdown));
 
-      /* Emit signal */
-      g_signal_emit_by_name (countdown, "finish");
+      /* If the countdown has passed the requested seconds, emit a 'finish' signal */
+      if (time_out_countdown_get_remaining (countdown) <= 0)
+        {
+          /* Set state to stopped */
+          time_out_countdown_stop (countdown);
+
+          /* Emit signal */
+          g_signal_emit_by_name (countdown, "finish");
+        }
     }
 
   return TRUE;
