@@ -1,7 +1,7 @@
-/* $Id: time-out-lock-screen.h 2892 2007-07-08 14:18:28Z jannis $ */
 /* vim:set et ai sw=2 sts=2: */
 /*-
  * Copyright (c) 2006 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2010 Florian Rivoal <frivoal@xfce.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -39,7 +39,8 @@ typedef struct _TimeOutLockScreen      TimeOutLockScreen;
 GType              time_out_lock_screen_get_type            (void) G_GNUC_CONST;
 
 TimeOutLockScreen *time_out_lock_screen_new                 (void) G_GNUC_MALLOC;
-void               time_out_lock_screen_show                (TimeOutLockScreen *lock_screen);
+void               time_out_lock_screen_show                (TimeOutLockScreen *lock_screen,
+                                                             gint               max_sec);
 void               time_out_lock_screen_hide                (TimeOutLockScreen *lock_screen);
 void               time_out_lock_screen_set_remaining       (TimeOutLockScreen *lock_screen,
                                                              gint               seconds);
@@ -49,6 +50,8 @@ void               time_out_lock_screen_set_display_hours   (TimeOutLockScreen *
                                                              gboolean           display_hours);
 void               time_out_lock_screen_set_allow_postpone  (TimeOutLockScreen *lock_screen,
                                                              gboolean           allow_postpone);
+void               time_out_lock_screen_show_resume         (TimeOutLockScreen *lock_screen,
+                                                             gboolean           auto_resume);
 
 G_END_DECLS;
 
